mail archive of the barebox mailing list
 help / color / mirror / Atom feed
From: Juergen Beisert <jbe@pengutronix.de>
To: barebox@lists.infradead.org
Subject: [PATCH 04/10] x86 Generic platform: Fix some typos
Date: Tue,  8 Mar 2011 15:48:18 +0100	[thread overview]
Message-ID: <1299595704-11733-5-git-send-email-jbe@pengutronix.de> (raw)
In-Reply-To: <1299595704-11733-1-git-send-email-jbe@pengutronix.de>

Signed-off-by: Juergen Beisert <jbe@pengutronix.de>
---
 arch/x86/boards/x86_generic/generic_pc.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/arch/x86/boards/x86_generic/generic_pc.c b/arch/x86/boards/x86_generic/generic_pc.c
index b9c31aa..e156e0d 100644
--- a/arch/x86/boards/x86_generic/generic_pc.c
+++ b/arch/x86/boards/x86_generic/generic_pc.c
@@ -58,7 +58,7 @@ extern uint16_t pers_env_size;
 extern uint8_t pers_env_drive;
 
 /**
  * Persistant environment "not used" marker.
  * Note: Must be in accordance to the value the tool "setup_mbr" writes.
  */
 #define PATCH_AREA_PERS_SIZE_UNUSED 0x000
@@ -80,7 +80,7 @@ static int devices_init(void)
 				DEVFS_PARTITION_FIXED, "env0");
 		printf("Partition: %d\n", rc);
 	} else
-		printf("No persistant storage defined\n");
+		printf("No persistent storage defined\n");
 
         return 0;
 }
@@ -58,7 +58,7 @@ extern uint16_t pers_env_size;
 
 /**
- * Persistant environment "not used" marker.
+ * Persistent environment "not used" marker.
  * Note: Must be in accordance to the value the tool "setup_mbr" writes.
  */
-- 
1.7.2.3


_______________________________________________
barebox mailing list
barebox@lists.infradead.org
http://lists.infradead.org/mailman/listinfo/barebox

  parent reply	other threads:[~2011-03-08 14:48 UTC|newest]

Thread overview: 12+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2011-03-08 14:48 [PATCH] Various fixes to make barebox's x86 support working again Juergen Beisert
2011-03-08 14:48 ` [PATCH 01/10] x86: Remove not used expressions from the makefile Juergen Beisert
2011-03-08 14:48 ` [PATCH 02/10] x86: Use the generic linker script initializing Juergen Beisert
2011-03-08 14:48 ` [PATCH 03/10] x86 ATA: Don't touch the size entry for the BIOS disk based device Juergen Beisert
2011-03-08 14:48 ` Juergen Beisert [this message]
2011-03-08 14:48 ` [PATCH 05/10] x86 Generic platform: Fix disk drive name Juergen Beisert
2011-03-08 14:48 ` [PATCH 06/10] x86 Generic platform: Fix prompt name Juergen Beisert
2011-03-08 14:48 ` [PATCH 07/10] x86: Remove 'uboot' from file names Juergen Beisert
2011-03-08 14:48 ` [PATCH 08/10] Change 'linux16' command to use getopt() Juergen Beisert
2011-03-08 14:48 ` [PATCH 09/10] LINUX16: Add selection of the VESA video mode Juergen Beisert
2011-03-08 14:48 ` [PATCH 10/10] LINUX16: Fix warning Juergen Beisert
  -- strict thread matches above, loose matches on Subject: below --
2011-01-07  8:35 Various fixes to make barebox's x86 support working again Juergen Beisert
2011-01-07  8:35 ` [PATCH 04/10] x86 Generic platform: Fix some typos Juergen Beisert

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1299595704-11733-5-git-send-email-jbe@pengutronix.de \
    --to=jbe@pengutronix.de \
    --cc=barebox@lists.infradead.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox